================================
oslo.log -- Oslo Logging Library
================================

OpenStack logging configuration library provides standardized configuration for
all openstack projects. It also provides custom formatters, handlers and
support for context specific logging (like resource id's etc).

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/oslo.log
* Source: http://git.openstack.org/cgit/openstack/oslo.log
* Bugs: http://bugs.launchpad.net/oslo.log
